@@ -79,7 +79,7 @@ STORAGE_CONFIG_SCHEMA = {
     'required': ['version', 'config'],
     'definitions': schemas.definitions,
     'properties': {
-        'version': {'type': 'integer', 'enum': [1]},
+        'version': {'type': 'integer', 'enum': [1, 2]},
         'config': {
             'type': 'array',
             'items': {
@@ -753,6 +753,8 @@ class BlockdevParser(ProbertParser):
             return entry
 
         if entry['type'] == 'partition':
+            if devname:
+                entry['path'] = devname
             attrs = blockdev_data['attrs']
             if self.is_mpath_partition(blockdev_data):
                 entry['number'] = int(blockdev_data['DM_PART'])
@@ -798,6 +800,8 @@ class BlockdevParser(ProbertParser):
                 entry['size'] *= 512
 
             ptype = blockdev_data.get('ID_PART_ENTRY_TYPE')
+            if ptype is not None:
+                entry['partition_type'] = ptype
             flag_name, _flag_code = ptable_uuid_to_flag_entry(ptype)
 
             if ptable and ptable.get('label') == 'dos':
@@ -1315,7 +1319,7 @@ def extract_storage_config(probe_data, strict=False):
     ordered = (dasd + disk + part + format + lvols + lparts + raids +
                dmcrypts + mounts + bcache + zpool + zfs)
 
-    final_config = {'storage': {'version': 1, 'config': ordered}}
+    final_config = {'storage': {'version': 2, 'config': ordered}}
     try:
         LOG.info('Validating extracted storage config components')
         validate_config(final_config['storage'])
@@ -1346,7 +1350,7 @@ def extract_storage_config(probe_data, strict=False):
 
     LOG.debug("Merging storage config dependencies")
     merged_config = {
-        'version': 1,
+        'version': 2,
         'config': merge_config_trees_to_list(ctrees)
     }
     LOG.debug("Merged storage config:\n%s",
@@ -1355,4 +1359,12 @@ def extract_storage_config(probe_data, strict=False):
     return {'storage': merged_config}
 
 
+def select_configs(storage_config, **kwargs):
+    """ Given a set of key=value arguments, return a list of the configs that
+        match all specified key-value pairs.
+    """
+    return [cfg for cfg in storage_config.values()
+            if all(cfg.get(k) == v for k, v in kwargs.items())]
+
+
 # vi: ts=4 expandtab syntax=python
