@@ -7,7 +7,7 @@ from curtin.storage_config import ProbertParser as baseparser
 from curtin.storage_config import (BcacheParser, BlockdevParser, DasdParser,
                                    DmcryptParser, FilesystemParser, LvmParser,
                                    RaidParser, MountParser, ZfsParser)
-from curtin.storage_config import ptable_uuid_to_flag_entry
+from curtin.storage_config import ptable_uuid_to_flag_entry, select_configs
 from curtin import util
 
 
@@ -285,7 +285,7 @@ class TestBlockdevParser(CiTestCase):
         """ BlockdevParser skips invalid ID_WWN_* values. """
         self.bdevp.blockdev_data['/dev/sda'] = {
             'DEVTYPE': 'disk',
-            'DEVNAME': 'sda',
+            'DEVNAME': '/dev/sda',
             'ID_SERIAL': 'Corsair_Force_GS_1785234921906',
             'ID_SERIAL_SHORT': '1785234921906',
             'ID_WWN': '0x0000000000000000',
@@ -300,7 +300,7 @@ class TestBlockdevParser(CiTestCase):
         """ BlockdevParser skips invalid ID_SERIAL_* values. """
         self.bdevp.blockdev_data['/dev/sda'] = {
             'DEVTYPE': 'disk',
-            'DEVNAME': 'sda',
+            'DEVNAME': '/dev/sda',
             'ID_SERIAL': '                      ',
             'ID_SERIAL_SHORT': 'My Serial is My PassPort',
         }
@@ -345,10 +345,12 @@ class TestBlockdevParser(CiTestCase):
             'id': 'partition-sda1',
             'type': 'partition',
             'device': 'disk-sda',
+            'path': '/dev/sda1',
             'number': 1,
             'offset': 1048576,
             'size': 499122176,
             'flag': 'linux',
+            'partition_type': '0fc63daf-8483-4772-8e79-3d69d8477de4',
         }
         self.assertDictEqual(expected_dict,
                              self.bdevp.asdict(blockdev))
@@ -375,12 +377,12 @@ class TestBlockdevParser(CiTestCase):
         """ BlockdevParser ignores partition with zero start value."""
         self.bdevp.blockdev_data['/dev/vda'] = {
             'DEVTYPE': 'disk',
-            'DEVNAME': 'vda',
+            'DEVNAME': '/dev/vda',
         }
         test_value = {
             'DEVTYPE': 'partition',
             'MAJOR': "252",
-            'DEVNAME': 'vda1',
+            'DEVNAME': '/dev/vda1',
             "DEVPATH":
                 "/devices/pci0000:00/0000:00:04.0/virtio0/block/vda/vda1",
             "ID_PART_ENTRY_TYPE": "0x0",
@@ -390,8 +392,10 @@ class TestBlockdevParser(CiTestCase):
             'id': 'partition-vda1',
             'type': 'partition',
             'device': 'disk-vda',
+            'path': '/dev/vda1',
             'number': 1,
             'size': 784334848,
+            'partition_type': '0x0',
         }
         self.assertDictEqual(expected_dict, self.bdevp.asdict(test_value))
 
@@ -403,7 +407,8 @@ class TestBlockdevParser(CiTestCase):
 
     # XXX: Parameterize me
     def test_blockdev_to_id_raises_valueerror_on_empty_devtype(self):
-        test_value = {'DEVTYPE': '', 'DEVNAME': 'bar', 'DEVPATH': 'foobar'}
+        test_value = {'DEVTYPE': '', 'DEVNAME': '/dev/bar',
+                      'DEVPATH': 'foobar'}
         with self.assertRaises(ValueError):
             self.bdevp.blockdev_to_id(test_value)
 
@@ -415,7 +420,7 @@ class TestBlockdevParser(CiTestCase):
 
     # XXX: Parameterize me
     def test_blockdev_to_id_raises_valueerror_on_missing_devtype(self):
-        test_value = {'DEVNAME': 'bar', 'DEVPATH': 'foobar'}
+        test_value = {'DEVNAME': '/dev/bar', 'DEVPATH': 'foobar'}
         with self.assertRaises(ValueError):
             self.bdevp.blockdev_to_id(test_value)
 
@@ -424,9 +429,10 @@ class TestBlockdevParser(CiTestCase):
         self.probe_data = _get_data('probert_storage_lvm.json')
         self.bdevp = BlockdevParser(self.probe_data)
         blockdev = self.bdevp.blockdev_data['/dev/vda2']
-        expected_dict = {
+        base_expected_dict = {
             'id': 'partition-vda2',
             'type': 'partition',
+            'path': '/dev/vda2',
             'device': 'disk-vda',
             'number': 2,
             'offset': 3222274048,
@@ -435,6 +441,8 @@ class TestBlockdevParser(CiTestCase):
         }
         for ext_part_entry in ['0xf', '0x5', '0x85', '0xc5']:
             blockdev['ID_PART_ENTRY_TYPE'] = ext_part_entry
+            expected_dict = base_expected_dict.copy()
+            expected_dict['partition_type'] = ext_part_entry
             self.assertDictEqual(expected_dict,
                                  self.bdevp.asdict(blockdev))
 
@@ -446,10 +454,12 @@ class TestBlockdevParser(CiTestCase):
             'id': 'partition-vda5',
             'type': 'partition',
             'device': 'disk-vda',
+            'path': '/dev/vda5',
             'number': 5,
             'offset': 3223322624,
             'size': 2147483648,
             'flag': 'logical',
+            'partition_type': '0x83',
         }
         self.assertDictEqual(expected_dict,
                              self.bdevp.asdict(blockdev))
@@ -463,10 +473,12 @@ class TestBlockdevParser(CiTestCase):
             'id': 'partition-vdb1',
             'type': 'partition',
             'device': 'disk-vdb',
+            'path': '/dev/vdb1',
             'number': 1,
             'offset': 1048576,
             'size': 536870912,
             'flag': 'boot',
+            'partition_type': '0xb',
         }
         self.assertDictEqual(expected_dict,
                              self.bdevp.asdict(blockdev))
@@ -480,10 +492,12 @@ class TestBlockdevParser(CiTestCase):
             'id': 'partition-vda5',
             'type': 'partition',
             'device': 'disk-vda',
+            'path': '/dev/vda5',
             'number': 5,
             'offset': 3223322624,
             'size': 2147483648,
             'flag': 'boot',
+            'partition_type': '0x83',
         }
         self.assertDictEqual(expected_dict,
                              self.bdevp.asdict(blockdev))
@@ -536,6 +550,7 @@ class TestBlockdevParser(CiTestCase):
         blockdev = self.bdevp.blockdev_data['/dev/dm-2']
         expected_dict = {
             'device': 'mpath-disk-mpatha',
+            'path': '/dev/dm-2',
             'flag': 'linux',
             'id': 'mpath-partition-mpatha-part2',
             'multipath': 'mpatha',
@@ -543,6 +558,7 @@ class TestBlockdevParser(CiTestCase):
             'offset': 2097152,
             'size': 10734272512,
             'type': 'partition',
+            'partition_type': '0fc63daf-8483-4772-8e79-3d69d8477de4',
             }
         self.assertDictEqual(expected_dict, self.bdevp.asdict(blockdev))
 
@@ -970,7 +986,7 @@ class TestExtractStorageConfig(CiTestCase):
         """ verify live-iso extracted storage-config finds target disk. """
         extracted = storage_config.extract_storage_config(self.probe_data)
         self.assertEqual(
-            {'storage': {'version': 1,
+            {'storage': {'version': 2,
                          'config': [{'id': 'disk-sda', 'path': '/dev/sda',
                                      'serial': 'QEMU_HARDDISK_QM00001',
                                      'type': 'disk'}]}}, extracted)
@@ -985,13 +1001,13 @@ class TestExtractStorageConfig(CiTestCase):
             if missing_key != 'blockdev':
                 self.assertEqual(
                     {'storage':
-                        {'version': 1,
+                        {'version': 2,
                          'config': [{'id': 'disk-sda', 'path': '/dev/sda',
                                      'serial': 'QEMU_HARDDISK_QM00001',
                                      'type': 'disk'}]}}, extracted)
             else:
                 # empty config without blockdev data
-                self.assertEqual({'storage': {'config': [], 'version': 1}},
+                self.assertEqual({'storage': {'config': [], 'version': 2}},
                                  extracted)
 
     @skipUnlessJsonSchema()
@@ -1010,10 +1026,17 @@ class TestExtractStorageConfig(CiTestCase):
                           'raidlevel': 'raid1', 'name': 'md1',
                           'devices': ['partition-vdb1', 'partition-vdc1'],
                           'spare_devices': []}, raids[0])
-        self.assertEqual({'id': 'raid-md1p1', 'type': 'partition',
-                          'size': 4285530112, 'flag': 'linux', 'number': 1,
-                          'device': 'raid-md1', 'offset': 1048576},
-                         raid_partitions[0])
+        self.assertEqual({
+            'id': 'raid-md1p1',
+            'type': 'partition',
+            'path': '/dev/md1p1',
+            'size': 4285530112,
+            'flag': 'linux',
+            'number': 1,
+            'partition_type': '0fc63daf-8483-4772-8e79-3d69d8477de4',
+            'device': 'raid-md1',
+            'offset': 1048576},
+            raid_partitions[0])
 
     @skipUnlessJsonSchema()
     def test_find_extended_partition(self):
@@ -1108,4 +1131,26 @@ class TestExtractStorageConfig(CiTestCase):
         self.assertEqual(expected_dict, bitlocker[0])
 
 
+class TestSelectConfigs(CiTestCase):
+    def test_basic(self):
+        id0 = {'a': 1, 'b': 2}
+        id1 = {'a': 1, 'c': 3}
+        sc = {'id0': id0, 'id1': id1}
+
+        self.assertEqual([id0, id1], select_configs(sc, a=1))
+
+    def test_not_found(self):
+        id0 = {'a': 1, 'b': 2}
+        id1 = {'a': 1, 'c': 3}
+        sc = {'id0': id0, 'id1': id1}
+
+        self.assertEqual([], select_configs(sc, a=4))
+
+    def test_multi_criteria(self):
+        id0 = {'a': 1, 'b': 2}
+        id1 = {'a': 1, 'c': 3}
+        sc = {'id0': id0, 'id1': id1}
+
+        self.assertEqual([id0], select_configs(sc, a=1, b=2))
+
 # vi: ts=4 expandtab syntax=python
